==> deepin-camera_6.0.11.tar.xz: BUILD/src/translations/deepin-camera_ug.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ug">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>سىن خاتىرىلەش خىزمىتى ئېلىپ بېرىلماقتا. كۆزنەكنى تاقامسىز؟</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">قىسقۇچنى ئېچىش</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>تەڭشەكلەر</translation>
    </message>
    <message>
        <source>None</source>
        <translation>يوق</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation>سۈرەت تارتىش</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>سىن ئېلىش</translation>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation>كامېرا ئالماشتۇرۇش</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>بىكار قىلىش</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>تاقاش</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>كۆپەيتىش</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>ئۆچۈرۈش</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>قىسقۇچنى ئېچىش</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>بېسىش</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>بۇ قىسقۇچنى بىر تەرەپ قىلىش ھوقۇقىڭىز يوق</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>تاقاش</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">ئىناۋەتسىز قىسقۇچ</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>قىسقۇچنى ئېچىش</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>تەڭشەكلەر</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>ئاساس</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>ھۆججەت ئورنى</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>تۇتۇش</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>جىددى ھالىتى</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>ئۆزلۈكىدىن كېچىكىش</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>چىقىرىش</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>چىقىرىش فورماتى</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 pcs</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 pcs</translation>
    </message>
    <message>
        <source>None</source>
        <translation>يوق</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>كامېرا</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>كامېرا كومپيۇتېرىڭىز ياكى كامېرا ئارقىلىق رەسىم ۋە سىنغا ئېلىش قورالى.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>ھۆججەت ساقلانمىدى</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">گە ساقلاش:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>فوتو:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>ۋېدىئو:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>ئېنىقلىق تەڭشىكى</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation type="vanished">ئېنىقلىقى:</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>رەسىم ساقلانغان ئورۇن:</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>سىن ساقلانغان ئورۇن:</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>ئاۋاز ئۈنۈمى</translation>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation>مەۋھۇم كامېرا</translation>
    </message>
    <message>
        <source>Flashlight</source>
        <translation>چاقماق لامپا</translation>
    </message>
    <message>
        <source>Gridlines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Maximum resolution:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>كامېرا</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>تەڭشەكلەر</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>ئېلىشنى توختىتىش</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>كۆپەيتىش</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>ئۆچۈرۈش</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>ئېچىش</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>بېسىش</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>ياردەم</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>تېزلەتمە كۆرۈنسۇن</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>سۈرئەتكە ئېلىشنى توختىتىش</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>ئوڭ كۇنۇپكا كۆرۈنسۇن</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation type="vanished">رەسىمگە تارتىش</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation type="vanished">سىنغا ئېلىش</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation type="vanished">سۈرئەتكە ئېلىشنى توختىتىش</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>يوق</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation>ئۆلچەملىك</translation>
    </message>
    <message>
        <source>Vivid</source>
        <translation>ئىنىقراق</translation>
    </message>
    <message>
        <source>Warm</source>
        <translation>ئېسسېق رەڭ</translation>
    </message>
    <message>
        <source>Cold</source>
        <translation>سوغۇق رەڭ</translation>
    </message>
    <message>
        <source>Retro</source>
        <translation>كونىچە</translation>
    </message>
    <message>
        <source>Film</source>
        <translation>بېسىش</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>كۈلرەڭ</translation>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation>ئاق-قارا</translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation>چاقماق لامپا</translation>
    </message>
    <message>
        <source>On</source>
        <translation>ئېچىش</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>تاقاش</translation>
    </message>
    <message>
        <source>Delay capture</source>
        <translation>ۋاقىت بەلگىلەپ تارتىش</translation>
    </message>
    <message>
        <source>None</source>
        <translation>يوق</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>سۈزگۈچ</translation>
    </message>
    <message>
        <source>Exposure</source>
        <translation>ئېكسپوزىتسىيە</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>تور كامېراسى تېپىلمىدى</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>تور كامېراسى خىزمەتتە</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation type="vanished">ئېلىشنى توختىتىش</translation>
    </message>
</context>
</TS>

==> deepin-camera_6.5.20.tar.xz: BUILD/src/translations/deepin-camera_ug.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ug">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>سىن خاتىرىلەش خىزمىتى ئېلىپ بېرىلماقتا. كۆزنەكنى تاقامسىز؟</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">قىسقۇچنى ئېچىش</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>تەڭشەكلەر</translation>
    </message>
    <message>
        <source>None</source>
        <translation>يوق</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation>سۈرەت تارتىش</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>سىن ئېلىش</translation>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation>كامېرا ئالماشتۇرۇش</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>بىكار قىلىش</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>تاقاش</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>كۆپەيتىش</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>ئۆچۈرۈش</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>قىسقۇچنى ئېچىش</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>بېسىش</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>بۇ قىسقۇچنى بىر تەرەپ قىلىش ھوقۇقىڭىز يوق</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>تاقاش</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">ئىناۋەتسىز قىسقۇچ</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>قىسقۇچنى ئېچىش</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>تەڭشەكلەر</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>ئاساس</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>ھۆججەت ئورنى</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>تۇتۇش</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>جىددى ھالىتى</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>ئۆزلۈكىدىن كېچىكىش</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>چىقىرىش</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>چىقىرىش فورماتى</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 pcs</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 pcs</translation>
    </message>
    <message>
        <source>None</source>
        <translation>يوق</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>كامېرا</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>كامېرا كومپيۇتېرىڭىز ياكى كامېرا ئارقىلىق رەسىم ۋە سىنغا ئېلىش قورالى.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>ھۆججەت ساقلانمىدى</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">گە ساقلاش:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>فوتو:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>ۋېدىئو:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>ئېنىقلىق تەڭشىكى</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation type="vanished">ئېنىقلىقى:</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>رەسىم ساقلانغان ئورۇن:</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>سىن ساقلانغان ئورۇن:</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>ئاۋاز ئۈنۈمى</translation>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation>مەۋھۇم كامېرا</translation>
    </message>
    <message>
        <source>Flashlight</source>
        <translation>چاقماق لامپا</translation>
    </message>
    <message>
        <source>Gridlines</source>
        <translation>بەدىئىي تۈزۈلمە تور</translation>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation>1*1 لىك تور</translation>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation>2*2 لىك تور</translation>
    </message>
    <message>
        <source>Maximum resolution:</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>كامېرا</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>تەڭشەكلەر</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>ئېلىشنى توختىتىش</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>كۆپەيتىش</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>ئۆچۈرۈش</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>ئېچىش</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>بېسىش</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>ياردەم</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>تېزلەتمە كۆرۈنسۇن</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>سۈرئەتكە ئېلىشنى توختىتىش</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>ئوڭ كۇنۇپكا كۆرۈنسۇن</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation type="vanished">رەسىمگە تارتىش</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation type="vanished">سىنغا ئېلىش</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation type="vanished">سۈرئەتكە ئېلىشنى توختىتىش</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>يوق</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation>ئۆلچەملىك</translation>
    </message>
    <message>
        <source>Vivid</source>
        <translation>ئىنىقراق</translation>
    </message>
    <message>
        <source>Warm</source>
        <translation>ئېسسېق رەڭ</translation>
    </message>
    <message>
        <source>Cold</source>
        <translation>سوغۇق رەڭ</translation>
    </message>
    <message>
        <source>Retro</source>
        <translation>كونىچە</translation>
    </message>
    <message>
        <source>Film</source>
        <translation>بېسىش</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>كۈلرەڭ</translation>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation>ئاق-قارا</translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation>چاقماق لامپا</translation>
    </message>
    <message>
        <source>On</source>
        <translation>ئېچىش</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>تاقاش</translation>
    </message>
    <message>
        <source>Delay capture</source>
        <translation>ۋاقىت بەلگىلەپ تارتىش</translation>
    </message>
    <message>
        <source>None</source>
        <translation>يوق</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>سۈزگۈچ</translation>
    </message>
    <message>
        <source>Exposure</source>
        <translation>ئېكسپوزىتسىيە</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>تور كامېراسى تېپىلمىدى</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>تور كامېراسى خىزمەتتە</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation type="vanished">ئېلىشنى توختىتىش</translation>
    </message>
</context>
</TS>
